"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var parsing_1 = require("./parsing");
describe('parsing', function () {
    describe('replaceTokens', function () {
        it('works with basic', function () {
            expect(parsing_1.replaceTokens({ 'type': '%{type}%' }, { type: 'internal' })).toEqual({ "type": "internal" });
        });
        it('does not replace keys', function () {
            expect(parsing_1.replaceTokens({ '%type%': '%{type}%' }, { type: 'malice' })).toEqual({ "%type%": "malice" });
        });
        it('works with nested', function () {
            var obj = {
                "name": "Dealership1",
                "city": "Beijing",
                "oranges": {
                    "orange1": "%{orange1}%",
                    "orange2": "blood",
                    "orange3": {
                        "type": "mandarin",
                        "brand": "%{brand3}%"
                    }
                }
            };
            expect(parsing_1.replaceTokens(obj, { 'orange1': 'navel', 'brand3': 'halo' })).toEqual({
                "city": "Beijing",
                "name": "Dealership1",
                "oranges": {
                    "orange1": "navel",
                    "orange2": "blood",
                    "orange3": {
                        "brand": "halo",
                        "type": "mandarin"
                    }
                }
            });
        });
    });
    describe('splitYamlIntoDocs', function () {
        var yaml = "---\naddendum:\n    - title: Outro\n      details: |\n        '1996'\n        A major record deal \n        and some international notoriety\n...\n---\n! some last minute edits\ntracks.1.title = Section(edited)\nblue = note will\n...\n---\n! final commit edits...\ntracks.1.title = Section(edited FINAL)\nblues = note will\n...\n---\n! ---final commit edits...\ntracks.1.title = Section(edited FINAL)\nblues = note will\n...\n";
        expect(parsing_1.splitYamlIntoDocs(yaml)).toEqual([
            "addendum:\n    - title: Outro\n      details: |\n        '1996'\n        A major record deal \n        and some international notoriety\n",
            "! some last minute edits\ntracks.1.title = Section(edited)\nblue = note will\n",
            "! final commit edits...\ntracks.1.title = Section(edited FINAL)\nblues = note will\n",
            "! ---final commit edits...\ntracks.1.title = Section(edited FINAL)\nblues = note will\n"
        ]);
    });
});
